clear all; close all; clc
% Kinetic experiment calculating the fluorescence per cell for different
% levels of rhamnose induction.
% GFPmut3: http://parts.igem.org/wiki/index.php?title=Part:BBa_E0040 (GFP of part I13504)
filename = 'Data_kinetic_experiment.xlsx';
num = xlsread(filename);
%% Variables
t_min                = 1;
t_max                = 83;                                          % Number of time points  

OD_matrix           = num(4:27,t_min:t_max);                        % Matrix with all OD600 measurements
GFP_488_matrix      = num(31:54,t_min:t_max);                       % Matrix with all fluoresence measurements (excitation at 488nm)
time                = num(2,t_min:t_max)./3600;                     % Vector with all time points


F_OD_rh_0_wt_GFP    = (GFP_488_matrix(1:3,:) - ...                  % Fluorescence divided by the OD600, csgA-GFPmut3 construct with 0% (w/v) rhamnose
    (GFP_488_matrix(4,1))) ./OD_matrix(1:3,:);                      % (corrected for background fluorescence)
F_OD_rh_2_wt_GFP    = (GFP_488_matrix(5:7,:) - ...                  % Fluorescence divided by the OD600, csgA-GFPmut3 construct with 0.2% (w/v) rhamnose   
    (GFP_488_matrix(8,1)))./OD_matrix(5:7,:);                       % (corrected for background fluorescence)
F_OD_rh_5_wt_GFP    = (GFP_488_matrix(9:11,:) - ...                 % Fluorescence divided by the OD600, csgA-GFPmut3 construct with 0.5% (w/v) rhamnose   
    (GFP_488_matrix(12,1)))./OD_matrix(9:11,:);                     % (corrected for background fluorescence)
F_OD_rh_0_wt_csgA   = (GFP_488_matrix(13:15,:) - ...                % Fluorescence divided by the OD600, csgA construct with 0% (w/v) rhamnose   
    (GFP_488_matrix(16,1)))./OD_matrix(13:15,:);                    % (corrected for background fluorescence)
F_OD_rh_2_wt_csgA   = (GFP_488_matrix(17:19,:) - ...                % Fluorescence divided by the OD600, csgA construct with 0.2% (w/v) rhamnose   
    (GFP_488_matrix(20,1)))./OD_matrix(17:19,:);                    % (corrected for background fluorescence)
F_OD_rh_5_wt_csgA   = (GFP_488_matrix(21:23,:) - ...                % Fluorescence divided by the OD600, csgA construct with 0.5% (w/v) rhamnose   
    (GFP_488_matrix(24,1)))./OD_matrix(21:23,:);                    % (corrected for background fluorescence)

mean_rh_0_wt_GFP    = mean(F_OD_rh_0_wt_GFP);                       % mean of the fluorescence divided by the OD600, csgA-GFPmut3 construct with 0% (w/v) rhamnose
mean_rh_2_wt_GFP    = mean(F_OD_rh_2_wt_GFP);                       % mean of the fluorescence divided by the OD600, csgA-GFPmut3 construct with 0.2% (w/v) rhamnose
mean_rh_5_wt_GFP    = mean(F_OD_rh_5_wt_GFP);                       % mean of the fluorescence divided by the OD600, csgA-GFPmut3 construct with 0.5% (w/v) rhamnose
mean_rh_0_wt_csgA   = mean(F_OD_rh_0_wt_csgA);                      % mean of the fluorescence divided by the OD600, csgA construct with 0% (w/v) rhamnose
mean_rh_2_wt_csgA   = mean(F_OD_rh_2_wt_csgA);                      % mean of the fluorescence divided by the OD600, csgA construct with 0.2% (w/v) rhamnose
mean_rh_5_wt_csgA   = mean(F_OD_rh_5_wt_csgA);                      % mean of the fluorescence divided by the OD600, csgA construct with 0.5% (w/v) rhamnose

mean_rh_0_wt_GFP_OD = mean(OD_matrix(1:3,:));                       % mean of the fluorescence divided by the OD600, csgA-GFPmut3 construct with 0% (w/v) rhamnose
mean_rh_2_wt_GFP_OD = mean(OD_matrix(5:7,:));                       % mean of the fluorescence divided by the OD600, csgA-GFPmut3 construct with 0.2% (w/v) rhamnose
mean_rh_5_wt_GFP_OD = mean(OD_matrix(9:11,:));                      % mean of the fluorescence divided by the OD600, csgA-GFPmut3 construct with 0.5% (w/v) rhamnose
mean_rh_0_wt_csgA_OD= mean(OD_matrix(13:15,:));                     % mean of the fluorescence divided by the OD600, csgA construct with 0% (w/v) rhamnose
mean_rh_2_wt_csgA_OD= mean(OD_matrix(17:19,:));                     % mean of the fluorescence divided by the OD600, csgA construct with 0.2% (w/v) rhamnose
mean_rh_5_wt_csgA_OD= mean(OD_matrix(21:23,:));                     % mean of the fluorescence divided by the OD600, csgA construct with 0.5% (w/v) rhamnose

std_rh_0_wt_GFP     = std(F_OD_rh_0_wt_GFP);                        % standard deviation of the fluorescence divided by the OD600, csgA-GFPmut3 construct with 0% (w/v) rhamnose
std_rh_2_wt_GFP     = std(F_OD_rh_2_wt_GFP);                        % standard deviation of the fluorescence divided by the OD600, csgA-GFPmut3 construct with 0.2% (w/v) rhamnose
std_rh_5_wt_GFP     = std(F_OD_rh_5_wt_GFP);                        % standard deviation of the fluorescence divided by the OD600, csgA-GFPmut3 construct with 0.5% (w/v) rhamnose
std_rh_0_wt_csgA    = std(F_OD_rh_0_wt_csgA);                       % standard deviation of the fluorescence divided by the OD600, csgA construct with 0% (w/v) rhamnose
std_rh_2_wt_csgA    = std(F_OD_rh_2_wt_csgA);                       % standard deviation of the fluorescence divided by the OD600, csgA construct with 0.2% (w/v) rhamnose
std_rh_5_wt_csgA    = std(F_OD_rh_5_wt_csgA);                       % standard deviation of the fluorescence divided by the OD600, csgA construct with 0.5% (w/v) rhamnose

std_rh_0_wt_GFP_OD  = std(OD_matrix(1:3,:));                        % standard deviation of the fluorescence divided by the OD600, csgA-GFPmut3 construct with 0% (w/v) rhamnose
std_rh_2_wt_GFP_OD  = std(OD_matrix(5:7,:));                        % standard deviation of the fluorescence divided by the OD600, csgA-GFPmut3 construct with 0.2% (w/v) rhamnose
std_rh_5_wt_GFP_OD  = std(OD_matrix(9:11,:));                       % standard deviation of the fluorescence divided by the OD600, csgA-GFPmut3 construct with 0.5% (w/v) rhamnose
std_rh_0_wt_csgA_OD = std(OD_matrix(13:15,:));                      % standard deviation of the fluorescence divided by the OD600, csgA construct with 0% (w/v) rhamnose
std_rh_2_wt_csgA_OD = std(OD_matrix(17:19,:));                      % standard deviation of the fluorescence divided by the OD600, csgA construct with 0.2% (w/v) rhamnose
std_rh_5_wt_csgA_OD = std(OD_matrix(21:23,:));                      % standard deviation of the fluorescence divided by the OD600, csgA construct with 0.5% (w/v) rhamnose

figure(1)
set(gca,'fontsize',20)
% csgA-GFP
plot(time,mean_rh_0_wt_GFP,'k','LineWidth',3);hold on
plot(time,mean_rh_2_wt_GFP,'m','LineWidth',3);hold on
plot(time,mean_rh_5_wt_GFP,'b','LineWidth',3);hold on
% csgA
plot(time,mean_rh_0_wt_csgA,'c','LineWidth',3);hold on
plot(time,mean_rh_2_wt_csgA,'y','LineWidth',3);hold on
plot(time,mean_rh_5_wt_csgA,'r','LineWidth',3);hold on
xlim([0 max(time)]); ylim([-0.1e4 8e4]);
xlabel('Time [h]'); ylabel('Fluoresence/OD_{600}'); hold on;
legend('Rhamnose 0% (w/v) csgA-GFPmut3','Rhamnose 0.2% (w/v) csgA-GFPmut3','Rhamnose 0.5% (w/v) csgA-GFPmut3','Rhamnose 0% (w/v) csgA','Rhamnose 0.2% (w/v) csgA','Rhamnose 0.5% (w/v) csgA','Location','NorthWest'); hold on;
for i = 1:9
errorbar(time(9.*i),mean_rh_0_wt_GFP(i.*9),std_rh_0_wt_GFP(i.*9),'rx','LineWidth',2)
errorbar(time(9.*i),mean_rh_2_wt_GFP(i.*9),std_rh_2_wt_GFP(i.*9),'rx','LineWidth',2)
errorbar(time(9.*i),mean_rh_5_wt_GFP(i.*9),std_rh_5_wt_GFP(i.*9),'rx','LineWidth',2)
errorbar(time(9.*i),mean_rh_0_wt_csgA(i.*9),std_rh_0_wt_csgA(i.*9),'rx','LineWidth',2)
errorbar(time(9.*i),mean_rh_2_wt_csgA(i.*9),std_rh_2_wt_csgA(i.*9),'rx','LineWidth',2)
errorbar(time(9.*i),mean_rh_5_wt_csgA(i.*9),std_rh_5_wt_csgA(i.*9),'rx','LineWidth',2)
end

figure(2)
set(gca,'fontsize',20)
time_max = 48;
% csgA-GFP
plot(time(1:time_max),mean_rh_0_wt_GFP_OD(1:time_max) ,'k','LineWidth',3);hold on
plot(time(1:time_max),mean_rh_2_wt_GFP_OD(1:time_max) ,'m','LineWidth',3);hold on
plot(time(1:time_max),mean_rh_5_wt_GFP_OD(1:time_max) ,'b','LineWidth',3);hold on
% csgA
plot(time(1:time_max),mean_rh_0_wt_csgA_OD(1:time_max) ,'c','LineWidth',3);hold on
plot(time(1:time_max),mean_rh_2_wt_csgA_OD(1:time_max) ,'y','LineWidth',3);hold on
plot(time(1:time_max),mean_rh_5_wt_csgA_OD(1:time_max) ,'r','LineWidth',3);hold on
xlim([0 time(time_max)]); ylim([0 1.4]);
xlabel('Time [h]'); ylabel('OD_{600}'); hold on;
legend('Rhamnose 0% (w/v) csgA-GFPmut3','Rhamnose 0.2% (w/v) csgA-GFPmut3','Rhamnose 0.5% (w/v) csgA-GFPmut3','Rhamnose 0% (w/v) csgA','Rhamnose 0.2% (w/v) csgA','Rhamnose 0.5% (w/v) csgA','Location','NorthWest'); hold on;




