clear all; close all; clc;
% Function that fits a calibration curve through data
filename                = 'GFP_fluorescence_data.xlsx';
num                     = xlsread(filename);                                            % Read the Excel file
num(1,:)                = [];                                                           % Delete first row
factor                  = 21;                                                           % Ratio of emission maxima for GFP mut3 relative to wtGFP
GFP_fluorescence_wt     = num(1,:);                                                     % wtGFP signal
back_ground_noise       = mean(num(2,3:4));                                             % Background noise
GFP_fluorescence_cor    = GFP_fluorescence_wt - back_ground_noise;                      % Fluorescence signal corrected for background noise
GFP_fluorescence        = factor.*GFP_fluorescence_cor;                                 % relate the GFPmut3 signal to wtGFP
num_zer                 = 3;                                                            % Include point (0,0) (no GFP, no fluorescence)
GFP_fluorescence        = [zeros(1,num_zer), GFP_fluorescence ];                        % Fluorescence signal 
GFP_vector              = linspace(0,400);                                              % GFP vector [ng]
n_GFP_vec               = [0, 50, 100, 200, 300];                                       % Concentrations of GFP which were made [ng]
GFP_fluorescence_vec    = [mean(GFP_fluorescence(1:num_zer)), mean(GFP_fluorescence(num_zer+1:num_zer+3)),...
    mean(GFP_fluorescence(num_zer+4:num_zer+6)), mean(GFP_fluorescence(num_zer+7:num_zer+9)),...
    mean(GFP_fluorescence(num_zer+10:end))];  
e                       = [std(GFP_fluorescence(1:num_zer)), ...
    std(GFP_fluorescence(num_zer+1:num_zer+3)), std(GFP_fluorescence(num_zer+4:num_zer+6)),...
    std(GFP_fluorescence(num_zer+7:num_zer+9)), std(GFP_fluorescence(num_zer+10:end))];  % Standard deviation
%% Linear regression
[r,m,b]                 = regression(n_GFP_vec ,GFP_fluorescence_vec);                   % r = r^2, m = slope, b = intercept
GFP_fluorescence_fitted = m.*GFP_vector;                                                 % Fluoresence signal 
r
%% Plot calibration curve with the measurements
figure(1) 
set(gca,'fontsize',20)
plot(GFP_vector ,GFP_fluorescence_fitted,'b','LineWidth',3); hold on
legend('R^2 = 0.9994');
errorbar(n_GFP_vec(2:end), GFP_fluorescence_vec(2:end),e(2:end),'kx','LineWidth',2); hold on
xlabel('GFPmut3 [ng]'); ylabel('Fluorescence');
ylim([0 max(GFP_fluorescence_fitted)]);
